@@ -1,10 +1,8 @@
 external code : char -> int = "%identity"
 val chr : int -> char
 val escaped : char -> string
-val lowercase : char -> char[@@ocaml.deprecated
-                              "Use Char.lowercase_ascii instead."]
-val uppercase : char -> char[@@ocaml.deprecated
-                              "Use Char.uppercase_ascii instead."]
+val lowercase : char -> char
+val uppercase : char -> char
 val lowercase_ascii : char -> char
 val uppercase_ascii : char -> char
 type t = char
