@@ -1,7 +1,7 @@
 (*
  * This file is part of Coccinelle, licensed under the terms of the GPL v2.
  * See copyright.txt in the Coccinelle source code for more information.
- * The Coccinelle source code can be obtained at http://coccinelle.lip6.fr
+ * The Coccinelle source code can be obtained at https://coccinelle.gitlabpages.inria.fr/website
  *)
 
 let debug_engine = ref false
@@ -12,6 +12,7 @@ let verbose_matcher = ref true
 let useEU = ref true
 
 let disallow_nested_exps = ref false
+let disallow_nested_types = ref false
 
 (* if this flag is not set, then break and continue are also error exits *)
 let only_return_is_error_exit = ref false
